@@ -5,7 +5,7 @@ import base64
 from xml.etree import ElementTree
 from urllib.parse import quote, unquote
 
-from alibabacloud_oss_util import models, verify_stream
+from alibabacloud_oss_util import verify_stream
 
 
 class Client:
@@ -452,13 +452,13 @@ class Client:
         Parse msg into a object
         @return the object
         """
+        err_fields = ('Code', 'Message', 'RequestId', 'HostId')
+        err_resp = {}
         et = ElementTree.fromstring(msg)
-        err_resp = models.ErrorResponse()
         if et.tag == 'Error':
             for lf in et:
-                if lf.tag in Client._FIELDS_MAP:
-                    key = Client._FIELDS_MAP[lf.tag]
-                    setattr(err_resp, key, lf.text)
+                if lf.tag in err_fields:
+                    err_resp[lf.tag] = lf.text
         return err_resp
 
     @staticmethod
@@ -598,12 +598,14 @@ class Client:
             resource += request.pathname
             if request.query and '?' not in resource:
                 resource += '?'
-            for k, v in request.query.items():
-                if k in Client.SIGN_KEY_LIST and v:
+
+            sorted_query_keys = sorted(list(request.query))
+            for k in sorted_query_keys:
+                if k in Client.SIGN_KEY_LIST and request.query.get(k):
                     if resource.endswith('?'):
-                        resource += '%s=%s' % (k, v)
+                        resource += '%s=%s' % (k, request.query.get(k))
                     else:
-                        resource += '&%s=%s' % (k, v)
+                        resource += '&%s=%s' % (k, request.query.get(k))
             signature = 'OSS %s:%s' % (access_key_id, Client._signature_v1(request, resource, access_key_secret))
         else:
             if addtional_headers:
